set

Function set 

pub fn set(
    path: &Path,
    key: &str,
    environment: &str,
    value: &str,
) -> Result<(), SecretError>
Stores value under key for environment, replacing any previous value in that slot and leaving every other environment alone.

Errors